==> castor-ddlgen-1.1.1-sources.jar: org/castor/ddlgen/schemaobject/DefaultForeignKey.java <==
/*
 * Copyright 2006 Le Duc Bao, Ralf Joachim
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.castor.ddlgen.schemaobject;

import org.castor.ddlgen.DDLGenConfiguration;

/**
 * Default foreign key.
 * 
 * @author <a href="mailto:leducbao AT gmail DOT com">Le Duc Bao</a>
 * @author <a href="mailto:ralf DOT joachim AT syscon DOT eu">Ralf Joachim</a>
 * @version $Revision: 5951 $ $Date: 2006-04-25 16:09:10 -0600 (Tue, 25 Apr 2006) $
 * @since 1.1
 */
public final class DefaultForeignKey extends ForeignKey  {
    //--------------------------------------------------------------------------

    /**
     * {@inheritDoc}
     */
    public String toCreateDDL() {
        String newline = getConfiguration().getStringValue(
                DDLGenConfiguration.NEWLINE_KEY, DDLGenConfiguration.DEFAULT_NEWLINE);

        StringBuffer sb = new StringBuffer();
        sb.append(newline).append(newline);
        sb.append("ALTER TABLE ").append(getTable().getName());
        sb.append(newline);
        sb.append("ADD CONSTRAINT ").append(getName());
        sb.append(newline);
        sb.append("FOREIGN KEY (").append(fieldNames()).append(')');
        sb.append(newline);
        sb.append("REFERENCES ").append(getReferenceTable().getName());
        sb.append(" (").append(referencedFieldNames()).append(')');
        sb.append(DDLGenConfiguration.DEFAULT_STATEMENT_DELIMITER);
        return sb.toString();
    }

    //--------------------------------------------------------------------------
}

==> castor-ddlgen-1.3.3-rc1-sources.jar: org/castor/ddlgen/schemaobject/DefaultForeignKey.java <==
/*
 * Copyright 2006 Le Duc Bao, Ralf Joachim
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.castor.ddlgen.schemaobject;

import org.castor.ddlgen.DDLGenConfiguration;
import org.castor.ddlgen.DDLWriter;

/**
 * Default foreign key.
 * 
 * @author <a href="mailto:leducbao AT gmail DOT com">Le Duc Bao</a>
 * @author <a href="mailto:ralf DOT joachim AT syscon DOT eu">Ralf Joachim</a>
 * @version $Revision: 8993 $ $Date: 2011-08-02 01:28:52 +0200 (Di, 02 Aug 2011) $
 * @since 1.1
 */
public final class DefaultForeignKey extends ForeignKey  {
    //--------------------------------------------------------------------------

    /**
     * {@inheritDoc}
     */
    public void toCreateDDL(final DDLWriter writer) {
        String delimiter = DDLGenConfiguration.DEFAULT_STATEMENT_DELIMITER;
        
        writer.println();
        writer.println();
        writer.println("ALTER TABLE {0}", new Object[] {getTable().getName()});
        writer.println("ADD CONSTRAINT {0}", new Object[] {getName()});
        writer.print("FOREIGN KEY (");
        fieldNames(writer);
        writer.println(")");
        writer.print("REFERENCES {0} (", new Object[] {getReferenceTable().getName()});
        referencedFieldNames(writer);
        writer.print(")");
        writer.print(delimiter);
    }

    //--------------------------------------------------------------------------
}
